Module translate

Module translate 

Structs

TranslateContext
Context for translating TL AST expressions to DataFusion expressions. locals maps variable names to their runtime values. Names not in locals are treated as column references.

Enums

LocalValue
Values that can be used as literals in translated expressions.

Functions

translate_expr
Translate a TL AST expression into a DataFusion Expr.