Functions
- is_
between - Check if a value is between low and high (inclusive).
- is_
email - Check if a string is a valid email address.
- is_
phone - Check if a string looks like a phone number.
- is_url
- Check if a string is a valid HTTP/HTTPS URL.
- levenshtein
- Compute the Levenshtein edit distance between two strings.
- soundex
- Compute the American Soundex code for a string.